@@ -74,8 +74,7 @@ def test_changelog():
                         pool.all_manager_ids,
                         OS_DEFINITIONS.keys(),
                         "mpm",
-                        "bitbar",
-                        "xbar",
+                        "bar-plugin",
                     )
                 )
             )
@@ -130,7 +129,7 @@ def test_labeller_rules():
 
     assert rules_labels
     # Check that all canonical labels are referenced in rules.
-    assert (canonical_labels - {"🔌 BitBar plugin", "📦 manager: mpm"}).issubset(
+    assert (canonical_labels - {"🔌 bar-plugin", "📦 manager: mpm"}).issubset(
         rules_labels
     )
 
